==> lms-1.6.1+libs.tar.gz: lms/modules/daemoninstancelist.php <==
<?php

/*
 * LMS version 1.6.1 Ishta
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: daemoninstancelist.php,v 1.1.2.1 2005/05/13 20:10:02 alec Exp $
 */

function GetInstanceList($hostid)
{
	global $LMS;
	$list = $LMS->DB->GetAll('SELECT id, name, description, module, crontab, priority, disabled FROM daemoninstances WHERE hostid=? ORDER BY priority, name', array($hostid));
	return $list;
}

$layout['pagetitle'] = trans('Instances List');

$hostid = $_GET['id'];

$instancelist = GetInstanceList($hostid);

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('instancelist', $instancelist);
$SMARTY->assign('hostid', $hostid);
$SMARTY->assign('hosts', $LMS->DB->GetAll('SELECT id, name FROM daemonhosts ORDER BY name'));
$SMARTY->display('daemoninstancelist.html');

?>

==> lms-1.7.4+libs.tar.gz: lms/modules/daemoninstancelist.php <==
<?php

/*
 * LMS version 1.7.4 Wraith
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: daemoninstancelist.php,v 1.5 2005/08/29 19:18:47 alec Exp $
 */

function GetInstanceList($hostid)
{
	global $DB;

	if($hostid)
		$where = 'WHERE hostid = '.$hostid;
		
	return $DB->GetAll('SELECT daemoninstances.id AS id, daemoninstances.name AS name, daemoninstances.description AS description, 
			module, crontab, priority, disabled, hosts.name AS hostname
			FROM daemoninstances LEFT JOIN hosts ON hosts.id = hostid '
			.$where. 
			' ORDER BY hostname, priority, name');
}

$layout['pagetitle'] = trans('Instances List');

$hostid = $_GET['id'];

$instancelist = GetInstanceList($hostid);

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('instancelist', $instancelist);
$SMARTY->assign('hostid', $hostid);
$SMARTY->assign('hosts', $DB->GetAll('SELECT id, name FROM hosts ORDER BY name'));
$SMARTY->display('daemoninstancelist.html');

?>
